@@ -12,7 +12,7 @@ static R_NativePrimitiveArgType grplasso_t[] = {
   REALSXP, REALSXP, REALSXP, INTSXP, INTSXP, INTSXP, INTSXP, REALSXP, INTSXP, REALSXP, STRSXP, INTSXP, INTSXP, REALSXP, REALSXP
 };
 static R_NativePrimitiveArgType grpSVM_t[] = {
-  REALSXP, REALSXP, INTSXP, REALSXP, INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP
+  REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, REALSXP, REALSXP, REALSXP
 };
 static R_NativePrimitiveArgType grpLR_t[] = {
   REALSXP, REALSXP, REALSXP, INTSXP, REALSXP, INTSXP, INTSXP, INTSXP, REALSXP, REALSXP, INTSXP, REALSXP, STRSXP, REALSXP, REALSXP, INTSXP, REALSXP
@@ -22,12 +22,12 @@ static R_NativePrimitiveArgType grpPR_t[] = {
 };
 static const R_CMethodDef c_Methods[] = {
   {"grplasso", (DL_FUNC) &grplasso, 15, grplasso_t},
-  {"grpSVM", (DL_FUNC) &grpSVM, 15, grpSVM_t},
+  {"grpSVM", (DL_FUNC) &grpSVM, 16, grpSVM_t},
   {"grpLR", (DL_FUNC) &grpLR, 17, grpLR_t},
   {"grpPR", (DL_FUNC) &grpPR, 17, grpPR_t},
   {NULL, NULL, 0, NULL}
 };
-void R_init_myLib(DllInfo *info)
+extern "C" void R_init_SAM(DllInfo *info)
 {
   R_registerRoutines(info, c_Methods, NULL, NULL, NULL);
   R_useDynamicSymbols(info, FALSE);
