@@ -51,9 +51,8 @@ extern "C" void grpPR(double *A, double* yy, double *lambda, int *nnlambda, doub
 
   ActNewtonSolver solver(obj, *param);
 
-  vector<vector<VectorXd> > beta_history;
-  double *sse = new double[nlambda];
-  solver.solve(sse, df);
+  vector<double> sse(nlambda, 0.0);
+  solver.solve(sse.data(), df);
 
   assert(solver.solution_path.size() == (unsigned int)nlambda);
   for (int i = 0; i < nlambda; i++) {
